[glib] GSettingsSchemaSource: fix parameter name in header



commit b227528f3291c8c4cfdfea057917edec63597ff8
Author: Ryan Lortie <desrt desrt ca>
Date:   Mon Oct 28 20:48:53 2013 -0700

    GSettingsSchemaSource: fix parameter name in header
    
    list_schemas() had the parameters called 'recursive' and 'non-recursive'
    in the header instead of 'relocatable'.  Fix that.

 gio/gsettingsschema.c |   17 ++++++++---------
 gio/gsettingsschema.h |    4 ++--
 2 files changed, 10 insertions(+), 11 deletions(-)
---
diff --git a/gio/gsettingsschema.h b/gio/gsettingsschema.h
index 90ef37a..9038939 100644
--- a/gio/gsettingsschema.h
+++ b/gio/gsettingsschema.h
@@ -54,8 +54,8 @@ GSettingsSchema *       g_settings_schema_source_lookup                 (GSettin
 GLIB_AVAILABLE_IN_2_40
 void                    g_settings_schema_source_list_schemas           (GSettingsSchemaSource   *source,
                                                                          gboolean                 recursive,
-                                                                         gchar                 
***non_recursive_schemas,
-                                                                         gchar                 
***recursive_schemas);
+                                                                         gchar                 
***non_relocatable,
+                                                                         gchar                 
***relocatable);
 
 #define                 G_TYPE_SETTINGS_SCHEMA                          (g_settings_schema_get_type ())
 GLIB_AVAILABLE_IN_2_32


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gio/gsettingsschema.c b/gio/gsettingsschema.c
index bdbb08d..10a8c2b 100644
--- a/gio/gsettingsschema.c
+++ b/gio/gsettingsschema.c
@@ -727,10 +727,9 @@ g_settings_schema_source_get_text_tables (GSettingsSchemaSource *source)
  * g_settings_schema_source_list_schemas:
  * @source: a #GSettingsSchemaSource
  * @recursive: if we should recurse
  * @non_relocatable_schemas: (out) (transfer full): the list of
  *   non-relocatable schemas
  * @relocatable_schemas: (out) (transfer full): the list of relocatable
  *   schemas
+ * @relocatable: (out) (transfer full): the list of relocatable schemas
  *
  * Lists the schemas in a given source.
  *
@@ -750,8 +749,8 @@ g_settings_schema_source_get_text_tables (GSettingsSchemaSource *source)
 void
 g_settings_schema_source_list_schemas (GSettingsSchemaSource   *source,
                                        gboolean                 recursive,
-                                       gchar                 ***non_relocatable_schemas,
-                                       gchar                 ***relocatable_schemas)
+                                       gchar                 ***non_relocatable,
+                                       gchar                 ***relocatable)
 {
   GHashTable *single, *reloc;
   GSettingsSchemaSource *s;
@@ -799,15 +798,15 @@ g_settings_schema_source_list_schemas (GSettingsSchemaSource   *source,
         break;
     }
 
-  if (non_relocatable_schemas)
+  if (non_relocatable)
     {
-      *non_relocatable_schemas = (gchar **) g_hash_table_get_keys_as_array (single, NULL);
+      *non_relocatable = (gchar **) g_hash_table_get_keys_as_array (single, NULL);
       g_hash_table_steal_all (single);
     }
 
-  if (relocatable_schemas)
+  if (relocatable)
     {
-      *relocatable_schemas = (gchar **) g_hash_table_get_keys_as_array (reloc, NULL);
+      *relocatable = (gchar **) g_hash_table_get_keys_as_array (reloc, NULL);
       g_hash_table_steal_all (reloc);
     }
 
@@ -727,10 +727,9 @@ g_settings_schema_source_get_text_tables (GSettingsSchemaSource *source)
  * @source: a #GSettingsSchemaSource
  * @recursive: if we should recurse
- * @non_relocatable_schemas: (out) (transfer full): the list of
- *   non-relocatable schemas
- * @relocatable_schemas: (out) (transfer full): the list of relocatable
+ * @non_relocatable: (out) (transfer full): the list of non-relocatable
  *   schemas